import { BrowserPlugin } from '@snowplow/browser-tracker-core';
import { AddToCartEvent, RemoveFromCartEvent, CommonEventProperties, EcommerceTransactionEvent, EcommerceTransactionItemEvent } from '@snowplow/tracker-core';
/**
 * Adds ecommerce and cart tracking
 */
declare function EcommercePlugin(): BrowserPlugin;
/**
 * Track an ecommerce transaction
 *
 * @param event - The event information
 * @param trackers - The tracker identifiers which the event will be sent to
 */
declare function addTrans(event: EcommerceTransactionEvent & CommonEventProperties, trackers?: Array<string>): void;
/**
 * Track an ecommerce transaction item
 *
 * @param event - The event information
 * @param trackers - The tracker identifiers which the event will be sent to
 */
declare function addItem(event: EcommerceTransactionItemEvent & CommonEventProperties, trackers?: Array<string>): void;
/**
 * Commit the ecommerce transaction
 *
 * @remarks
 * This call will send the data specified with addTrans, ddItem methods to the tracking server.
 */
declare function trackTrans(trackers?: Array<string>): void;
/**
 * Track an add-to-cart event
 *
 * @param event - The event information
 * @param trackers - The tracker identifiers which the event will be sent to
 */
declare function trackAddToCart(event: AddToCartEvent & CommonEventProperties, trackers?: Array<string>): void;
/**
 * Track a remove-from-cart event
 *
 * @param event - The event information
 * @param trackers - The tracker identifiers which the event will be sent to
 */
declare function trackRemoveFromCart(event: RemoveFromCartEvent & CommonEventProperties, trackers?: Array<string>): void;
export { AddToCartEvent, RemoveFromCartEvent, EcommerceTransactionEvent, EcommerceTransactionItemEvent, EcommercePlugin, addTrans, addItem, trackTrans, trackAddToCart, trackRemoveFromCart };
